==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DNewInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DNewInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ab6d44320d529d95 soot_dava_internal_javaRep_DNewInvokeExpr
// @dep_class cd709234ad0500ea soot_grimp_internal_GNewInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GNewInvokeExpr

#include "soot/grimp/internal/GNewInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewInvokeExpr$method$_init$e3abae59b1e40b38(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *, struct _jc_soot_RefType$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods	soot_grimp_internal_GNewInvokeExpr;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods	soot_dava_internal_javaRep_DNewInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs	soot_dava_internal_javaRep_DNewInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DNewInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DNewInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DNewInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ab6d44320d529d95 soot_dava_internal_javaRep_DNewInvokeExpr
// @dep_class cd709234ad0500ea soot_grimp_internal_GNewInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GNewInvokeExpr

#include "soot/grimp/internal/GNewInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewInvokeExpr$method$_init$e3abae59b1e40b38(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *, struct _jc_soot_RefType$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods	soot_grimp_internal_GNewInvokeExpr;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vmethods	soot_dava_internal_javaRep_DNewInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_refs	soot_dava_internal_javaRep_DNewInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_dava_internal_javaRep_DNewInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DNewInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewInvokeExpr_H_ */
